( cd usr/share/doc/HTML/ru/thesaurus ; rm -rf common )
( cd usr/share/doc/HTML/ru/thesaurus ; ln -sf /usr/share/doc/HTML/ru//common common )
( cd usr/share/doc/HTML/ru/calligra ; rm -rf common )
( cd usr/share/doc/HTML/ru/calligra ; ln -sf /usr/share/doc/HTML/ru//common common )
( cd usr/share/doc/HTML/ru/sheets ; rm -rf common )
( cd usr/share/doc/HTML/ru/sheets ; ln -sf /usr/share/doc/HTML/ru//common common )
